==> mingw-w64-starpu-1.4.7-1.src.tar.zst: starpu-1.4.7/doc/doxygen_web_basics/html_web_basics/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Basics", "index.html", [
    [ "StarPU Applications, setting up Your Own Code", "StarPUApplications.html", [
      [ "Setting Flags for Compiling, Linking and Running Applications", "StarPUApplications.html#SettingFlagsForCompilingLinkingAndRunningApplications", null ],
      [ "Integrating StarPU in a Build System", "StarPUApplications.html#IntegratingStarPUInABuildSystem", [
        [ "Integrating StarPU in a Make Build System", "StarPUApplications.html#StarPUInMake", null ],
        [ "Integrating StarPU in a CMake Build System", "StarPUApplications.html#StarPUInCMake", null ]
      ] ],
      [ "Running a Basic StarPU Application", "StarPUApplications.html#RunningABasicStarPUApplication", null ],
      [ "Running a Basic StarPU Application on Microsoft Visual C", "StarPUApplications.html#RunningABasicStarPUApplicationOnMicrosoft", null ],
      [ "Kernel Threads Started by StarPU", "StarPUApplications.html#KernelThreadsStartedByStarPU", null ],
      [ "Enabling OpenCL", "StarPUApplications.html#EnablingOpenCL", null ],
      [ "Storing Performance Model Files", "StarPUApplications.html#Storing_Performance_Model_Files", null ]
    ] ],
    [ "Basic Examples", "BasicExamples.html", [
      [ "Hello World", "BasicExamples.html#HelloWorldUsingStarPUAPI", [
        [ "Required Headers", "BasicExamples.html#RequiredHeaders", null ],
        [ "Defining A Codelet", "BasicExamples.html#DefiningACodelet", null ],
        [ "Submitting A Task", "BasicExamples.html#SubmittingATask", null ],
        [ "Execution Of Hello World", "BasicExamples.html#ExecutionOfHelloWorld", null ],
        [ "Passing Arguments To The Codelet", "BasicExamples.html#PassingArgumentsToTheCodelet", null ],
        [ "Defining A Callback", "BasicExamples.html#DefiningACallback", null ],
        [ "Where To Execute A Codelet", "BasicExamples.html#WhereToExecuteACodelet", null ]
      ] ],
      [ "Vector Scaling", "BasicExamples.html#VectorScalingUsingStarPUAPI", [
        [ "Source Code of Vector Scaling", "BasicExamples.html#SourceCodeOfVectorScaling", null ],
        [ "Execution of Vector Scaling", "BasicExamples.html#ExecutionOfVectorScaling", null ]
      ] ],
      [ "Vector Scaling on an Hybrid CPU/GPU Machine", "BasicExamples.html#VectorScalingOnAnHybridCPUGPUMachine", [
        [ "Definition of the CUDA Kernel", "BasicExamples.html#DefinitionOfTheCUDAKernel", null ],
        [ "Definition of the OpenCL Kernel", "BasicExamples.html#DefinitionOfTheOpenCLKernel", null ],
        [ "Definition of the Main Code", "BasicExamples.html#DefinitionOfTheMainCode", null ],
        [ "Execution of Hybrid Vector Scaling", "BasicExamples.html#ExecutionOfHybridVectorScaling", null ]
      ] ]
    ] ],
    [ "Full source code for the ’Scaling a Vector’ example", "FullSourceCodeVectorScal.html", [
      [ "Main Application", "FullSourceCodeVectorScal.html#MainApplication", null ],
      [ "CPU Kernel", "FullSourceCodeVectorScal.html#CPUKernel", null ],
      [ "CUDA Kernel", "FullSourceCodeVectorScal.html#CUDAKernel", null ],
      [ "OpenCL Kernel", "FullSourceCodeVectorScal.html#OpenCLKernel", [
        [ "Invoking the Kernel", "FullSourceCodeVectorScal.html#InvokingtheKernel", null ],
        [ "Source of the Kernel", "FullSourceCodeVectorScal.html#SourceoftheKernel", null ]
      ] ]
    ] ],
    [ "Tasks In StarPU", "TasksInStarPU.html", [
      [ "Task Granularity", "TasksInStarPU.html#TaskGranularity", null ],
      [ "Task Submission", "TasksInStarPU.html#TaskSubmission", null ],
      [ "Task Priorities", "TasksInStarPU.html#TaskPriorities", null ],
      [ "Setting Many Data Handles For a Task", "TasksInStarPU.html#SettingManyDataHandlesForATask", null ],
      [ "Setting a Variable Number Of Data Handles For a Task", "TasksInStarPU.html#SettingVariableDataHandlesForATask", null ],
      [ "Insert Task Utility", "TasksInStarPU.html#InsertTaskUtility", null ],
      [ "Other Task Utility Functions", "TasksInStarPU.html#OtherTaskUtility", null ]
    ] ],
    [ "Data Management", "DataManagement.html", [
      [ "Data Interface", "DataManagement.html#DataInterface", [
        [ "Variable Data Interface", "DataManagement.html#VariableDataInterface", null ],
        [ "Vector Data Interface", "DataManagement.html#VectorDataInterface", null ],
        [ "Matrix Data Interface", "DataManagement.html#MatrixDataInterface", null ],
        [ "Block Data Interface", "DataManagement.html#BlockDataInterface", null ],
        [ "Tensor Data Interface", "DataManagement.html#TensorDataInterface", null ],
        [ "Ndim Data Interface", "DataManagement.html#NdimDataInterface", null ],
        [ "BCSR Data Interface", "DataManagement.html#BCSRDataInterface", null ],
        [ "CSR Data Interface", "DataManagement.html#CSRDataInterface", null ],
        [ "COO Data Interface", "DataManagement.html#COODataInterface", null ]
      ] ],
      [ "Partitioning Data", "DataManagement.html#PartitioningData", null ],
      [ "Asynchronous Partitioning", "DataManagement.html#AsynchronousPartitioning", null ],
      [ "Commute Data Access", "DataManagement.html#DataCommute", null ],
      [ "Data Reduction", "DataManagement.html#DataReduction", null ],
      [ "Concurrent Data Accesses", "DataManagement.html#ConcurrentDataAccess", null ],
      [ "Temporary Buffers", "DataManagement.html#TemporaryBuffers", [
        [ "Temporary Data", "DataManagement.html#TemporaryData", null ],
        [ "Scratch Data", "DataManagement.html#ScratchData", null ]
      ] ]
    ] ],
    [ "Scheduling", "Scheduling.html", [
      [ "Task Scheduling Policies", "Scheduling.html#TaskSchedulingPolicy", [
        [ "Non Performance Modelling Policies", "Scheduling.html#NonPerformanceModelingPolicies", null ],
        [ "Performance Model-Based Task Scheduling Policies", "Scheduling.html#DMTaskSchedulingPolicy", null ],
        [ "Modularized Schedulers", "Scheduling.html#ExistingModularizedSchedulers", null ]
      ] ],
      [ "Task Distribution Vs Data Transfer", "Scheduling.html#TaskDistributionVsDataTransfer", null ]
    ] ],
    [ "Examples in StarPU Sources", "ExamplesInStarPUSources.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BasicExamples.html",
"group__API__Codelet__And__Tasks.html#a84b67cae77eb44496f782910072b8279",
"group__API__Data__Interfaces.html#aaff7aa638a24957eb76c5c40f96cddbe",
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4",
"group__API__FFT__Support.html#gabff378384df24d2c2ea296397b600569",
"group__API__Interop__Support.html#gad16a15386b4f7b1f8156a6b6db93db3f",
"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d",
"group__API__Parallel__Worker.html#ga6418a1fed34b32217d66860cbf8fc200",
"group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef",
"group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb",
"group__API__Workers.html#ga38c0b1858730fec2211991147a964910",
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html",
"interfacestarpu__mod_1_1starpu__asynchronous__copy__disabled.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.9-1.src.tar.zst: starpu-1.4.9/doc/doxygen_web_basics/html_web_basics/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Basics", "index.html", [
    [ "StarPU Applications, setting up Your Own Code", "StarPUApplications.html", [
      [ "Setting Flags for Compiling, Linking and Running Applications", "StarPUApplications.html#SettingFlagsForCompilingLinkingAndRunningApplications", null ],
      [ "Integrating StarPU in a Build System", "StarPUApplications.html#IntegratingStarPUInABuildSystem", [
        [ "Integrating StarPU in a Make Build System", "StarPUApplications.html#StarPUInMake", null ],
        [ "Integrating StarPU in a CMake Build System", "StarPUApplications.html#StarPUInCMake", null ]
      ] ],
      [ "Running a Basic StarPU Application", "StarPUApplications.html#RunningABasicStarPUApplication", null ],
      [ "Running a Basic StarPU Application on Microsoft Visual C", "StarPUApplications.html#RunningABasicStarPUApplicationOnMicrosoft", null ],
      [ "Kernel Threads Started by StarPU", "StarPUApplications.html#KernelThreadsStartedByStarPU", null ],
      [ "Enabling OpenCL", "StarPUApplications.html#EnablingOpenCL", null ],
      [ "Storing Performance Model Files", "StarPUApplications.html#Storing_Performance_Model_Files", null ]
    ] ],
    [ "Basic Examples", "BasicExamples.html", [
      [ "Hello World", "BasicExamples.html#HelloWorldUsingStarPUAPI", [
        [ "Required Headers", "BasicExamples.html#RequiredHeaders", null ],
        [ "Defining A Codelet", "BasicExamples.html#DefiningACodelet", null ],
        [ "Submitting A Task", "BasicExamples.html#SubmittingATask", null ],
        [ "Execution Of Hello World", "BasicExamples.html#ExecutionOfHelloWorld", null ],
        [ "Passing Arguments To The Codelet", "BasicExamples.html#PassingArgumentsToTheCodelet", null ],
        [ "Defining A Callback", "BasicExamples.html#DefiningACallback", null ],
        [ "Where To Execute A Codelet", "BasicExamples.html#WhereToExecuteACodelet", null ]
      ] ],
      [ "Vector Scaling", "BasicExamples.html#VectorScalingUsingStarPUAPI", [
        [ "Source Code of Vector Scaling", "BasicExamples.html#SourceCodeOfVectorScaling", null ],
        [ "Execution of Vector Scaling", "BasicExamples.html#ExecutionOfVectorScaling", null ]
      ] ],
      [ "Vector Scaling on an Hybrid CPU/GPU Machine", "BasicExamples.html#VectorScalingOnAnHybridCPUGPUMachine", [
        [ "Definition of the CUDA Kernel", "BasicExamples.html#DefinitionOfTheCUDAKernel", null ],
        [ "Definition of the OpenCL Kernel", "BasicExamples.html#DefinitionOfTheOpenCLKernel", null ],
        [ "Definition of the Main Code", "BasicExamples.html#DefinitionOfTheMainCode", null ],
        [ "Execution of Hybrid Vector Scaling", "BasicExamples.html#ExecutionOfHybridVectorScaling", null ]
      ] ]
    ] ],
    [ "Full source code for the ’Scaling a Vector’ example", "FullSourceCodeVectorScal.html", [
      [ "Main Application", "FullSourceCodeVectorScal.html#MainApplication", null ],
      [ "CPU Kernel", "FullSourceCodeVectorScal.html#CPUKernel", null ],
      [ "CUDA Kernel", "FullSourceCodeVectorScal.html#CUDAKernel", null ],
      [ "OpenCL Kernel", "FullSourceCodeVectorScal.html#OpenCLKernel", [
        [ "Invoking the Kernel", "FullSourceCodeVectorScal.html#InvokingtheKernel", null ],
        [ "Source of the Kernel", "FullSourceCodeVectorScal.html#SourceoftheKernel", null ]
      ] ]
    ] ],
    [ "Tasks In StarPU", "TasksInStarPU.html", [
      [ "Task Granularity", "TasksInStarPU.html#TaskGranularity", null ],
      [ "Task Submission", "TasksInStarPU.html#TaskSubmission", null ],
      [ "Task Priorities", "TasksInStarPU.html#TaskPriorities", null ],
      [ "Setting Many Data Handles For a Task", "TasksInStarPU.html#SettingManyDataHandlesForATask", null ],
      [ "Setting a Variable Number Of Data Handles For a Task", "TasksInStarPU.html#SettingVariableDataHandlesForATask", null ],
      [ "Insert Task Utility", "TasksInStarPU.html#InsertTaskUtility", null ],
      [ "Other Task Utility Functions", "TasksInStarPU.html#OtherTaskUtility", null ]
    ] ],
    [ "Data Management", "DataManagement.html", [
      [ "Data Interface", "DataManagement.html#DataInterface", [
        [ "Variable Data Interface", "DataManagement.html#VariableDataInterface", null ],
        [ "Vector Data Interface", "DataManagement.html#VectorDataInterface", null ],
        [ "Matrix Data Interface", "DataManagement.html#MatrixDataInterface", null ],
        [ "Block Data Interface", "DataManagement.html#BlockDataInterface", null ],
        [ "Tensor Data Interface", "DataManagement.html#TensorDataInterface", null ],
        [ "Ndim Data Interface", "DataManagement.html#NdimDataInterface", null ],
        [ "BCSR Data Interface", "DataManagement.html#BCSRDataInterface", null ],
        [ "CSR Data Interface", "DataManagement.html#CSRDataInterface", null ],
        [ "COO Data Interface", "DataManagement.html#COODataInterface", null ]
      ] ],
      [ "Partitioning Data", "DataManagement.html#PartitioningData", null ],
      [ "Asynchronous Partitioning", "DataManagement.html#AsynchronousPartitioning", null ],
      [ "Commute Data Access", "DataManagement.html#DataCommute", null ],
      [ "Data Reduction", "DataManagement.html#DataReduction", null ],
      [ "Concurrent Data Accesses", "DataManagement.html#ConcurrentDataAccess", null ],
      [ "Temporary Buffers", "DataManagement.html#TemporaryBuffers", [
        [ "Temporary Data", "DataManagement.html#TemporaryData", null ],
        [ "Scratch Data", "DataManagement.html#ScratchData", null ]
      ] ]
    ] ],
    [ "Scheduling", "Scheduling.html", [
      [ "Task Scheduling Policies", "Scheduling.html#TaskSchedulingPolicy", [
        [ "Non Performance Modelling Policies", "Scheduling.html#NonPerformanceModelingPolicies", null ],
        [ "Performance Model-Based Task Scheduling Policies", "Scheduling.html#DMTaskSchedulingPolicy", null ],
        [ "Modularized Schedulers", "Scheduling.html#ExistingModularizedSchedulers", null ]
      ] ],
      [ "Task Distribution Vs Data Transfer", "Scheduling.html#TaskDistributionVsDataTransfer", null ]
    ] ],
    [ "Examples in StarPU Sources", "ExamplesInStarPUSources.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BasicExamples.html",
"group__API__Codelet__And__Tasks.html#a840563895dbf036b6ffd783a8ea2504d",
"group__API__Data__Interfaces.html#aad762e1231c7623b5831de7839b91a53",
"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a",
"group__API__FFT__Support.html#ga642104c645445688177f1a44afeeefb0",
"group__API__Interop__Support.html#gaba890f505d0373ec0da5ca4a87e23d3c",
"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5",
"group__API__Parallel__Worker.html#ga4e3f3eec12a1cd4285a3f8938a9c240d",
"group__API__Profiling.html#ade189cd6175d789db1eb6bfad19b3e35",
"group__API__Scheduling__Policy.html#a81af53e5f8e59cb12d6d0b378c4b5268",
"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9",
"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__wait.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
